==> nextcloud-18.0.4.tgz: nextcloud/apps/comments/l10n/af.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentare",
    "You commented" : "U het kommentaar gelewer",
    "%1$s commented" : "%1$s het kommentaar gelewer",
    "{author} commented" : "{outeur} het kommentaar gelewer",
    "You commented on %1$s" : "U het op %1$s kommentaar gelewer",
    "You commented on {file}" : "U het op {lêer} kommentaar gelewer",
    "%1$s commented on %2$s" : "%1$s het op %2$s kommentaar gelewer",
    "{author} commented on {file}" : "{outeur} het op {lêer} kommentaar gelewer",
    "<strong>Comments</strong> for files" : "<strong>Kommentare</strong> vir lêers",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Jy is genoem op “{lêer}”, in die kommentaar van 'n gebruiker wat intussen geskrap is.",
    "{user} mentioned you in a comment on “{file}”" : "{gebruiker} het u in ’n kommentaar oor “{lêer}” genoem",
    "Files app plugin to add comments to files" : "Lêertoepinprop om kommentaar op lêers te lewer",
    "Edit comment" : "Wysig kommentaar",
    "Delete comment" : "Skrap kommentaar",
    "New comment …" : "Nuwe kommentaar…",
    "Post" : "Plaas",
    "Cancel" : "Kanselleer",
    "[Deleted user]" : "[Geskrapte gebruiker]",
    "No comments yet, start the conversation!" : "Nog geen kommentaar, begin die gesprek!",
    "More comments …" : "Nog kommentare …",
    "Save" : "Bewaar",
    "Allowed characters {count} of {max}" : "Toegelate karakters {telling} van {maks}",
    "Error occurred while retrieving comment with ID {id}" : "’n Fout het voorgekom toe kommentaar met ID {id} opgehaal is",
    "Error occurred while updating comment with id {id}" : "’n Fout het voorgekom toe kommentaar met ID {id} bygewerk is",
    "Error occurred while posting comment" : "’n Fout het voorgekom toe kommentaar geplaas is",
    "_%n unread comment_::_%n unread comments_" : ["%n ongelese kommentaar","%n ongelese kommentare"],
    "Comment" : "Kommentaar"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.0p0.tgz: nextcloud/apps/comments/l10n/af.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentare",
    "You commented" : "U het kommentaar gelewer",
    "%1$s commented" : "%1$s het kommentaar gelewer",
    "{author} commented" : "{outeur} het kommentaar gelewer",
    "You commented on %1$s" : "U het op %1$s kommentaar gelewer",
    "You commented on {file}" : "U het op {lêer} kommentaar gelewer",
    "%1$s commented on %2$s" : "%1$s het op %2$s kommentaar gelewer",
    "{author} commented on {file}" : "{outeur} het op {lêer} kommentaar gelewer",
    "<strong>Comments</strong> for files" : "<strong>Kommentare</strong> vir lêers",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Jy is genoem op “{lêer}”, in die kommentaar van 'n gebruiker wat intussen geskrap is.",
    "{user} mentioned you in a comment on “{file}”" : "{gebruiker} het u in ’n kommentaar oor “{lêer}” genoem",
    "Files app plugin to add comments to files" : "Lêertoepinprop om kommentaar op lêers te lewer",
    "Edit comment" : "Wysig kommentaar",
    "Delete comment" : "Skrap kommentaar",
    "No comments yet, start the conversation!" : "Nog geen kommentaar, begin die gesprek!",
    "Retry" : "Herprobeer",
    "_%n unread comment_::_%n unread comments_" : ["%n ongelese kommentaar","%n ongelese kommentare"],
    "Comment" : "Kommentaar",
    "New comment …" : "Nuwe kommentaar…",
    "Post" : "Plaas",
    "Cancel" : "Kanselleer",
    "[Deleted user]" : "[Geskrapte gebruiker]",
    "More comments …" : "Nog kommentare …",
    "Save" : "Bewaar",
    "Allowed characters {count} of {max}" : "Toegelate karakters {telling} van {maks}",
    "Error occurred while retrieving comment with ID {id}" : "’n Fout het voorgekom toe kommentaar met ID {id} opgehaal is",
    "Error occurred while updating comment with id {id}" : "’n Fout het voorgekom toe kommentaar met ID {id} bygewerk is",
    "Error occurred while posting comment" : "’n Fout het voorgekom toe kommentaar geplaas is"
},
"nplurals=2; plural=(n != 1);");
